@@ -15,6 +15,7 @@
 #include "formlayoutattached.h"
 #include "icon.h"
 #include "imagecolors.h"
+#include "inputmethod.h"
 #include "mnemonicattached.h"
 #include "pagepool.h"
 #include "pagerouter.h"
@@ -25,8 +26,8 @@
 #include "sizegroup.h"
 #include "spellcheckinghint.h"
 #include "toolbarlayout.h"
-#include "wheelhandler.h"
 #include "units.h"
+#include "wheelhandler.h"
 
 #include <QClipboard>
 #include <QGuiApplication>
@@ -45,7 +46,6 @@ static QString s_selectedStyle;
 
 #ifdef KIRIGAMI_BUILD_TYPE_STATIC
 #include "loggingcategory.h"
-#include "qrc_kirigami.cpp"
 #include <QDebug>
 #endif
 
@@ -309,10 +309,18 @@ void KirigamiPlugin::registerTypes(const char *uri)
     
     // 2.19
     qmlRegisterType(componentUrl(QStringLiteral("AboutItem.qml")), uri, 2, 19, "AboutItem");
-
-    // 2.19
     qmlRegisterType(componentUrl(QStringLiteral("NavigationTabBar.qml")), uri, 2, 19, "NavigationTabBar");
     qmlRegisterType(componentUrl(QStringLiteral("NavigationTabButton.qml")), uri, 2, 19, "NavigationTabButton");
+    qmlRegisterType(componentUrl(QStringLiteral("Dialog.qml")), uri, 2, 19, "Dialog");
+    qmlRegisterType(componentUrl(QStringLiteral("MenuDialog.qml")), uri, 2, 19, "MenuDialog");
+    qmlRegisterType(componentUrl(QStringLiteral("PromptDialog.qml")), uri, 2, 19, "PromptDialog");
+    qmlRegisterType(componentUrl(QStringLiteral("AbstractChip.qml")), uri, 2, 19, "AbstractChip");
+    qmlRegisterType(componentUrl(QStringLiteral("Chip.qml")), uri, 2, 19, "Chip");
+    qmlRegisterType(componentUrl(QStringLiteral("LoadingPlaceholder.qml")), uri, 2, 19, "LoadingPlaceholder");
+
+    qmlRegisterSingletonType<InputMethod>(uri, 2, 19, "InputMethod", [](QQmlEngine *, QJSEngine *) {
+        return new InputMethod{};
+    });
 
     qmlProtectModule(uri, 2);
 }
@@ -333,6 +341,8 @@ KirigamiPlugin& KirigamiPlugin::getInstance()
 void KirigamiPlugin::registerTypes(QQmlEngine* engine)
 {
     Q_INIT_RESOURCE(shaders);
+    Q_INIT_RESOURCE(KirigamiPlugin);
+
     if (engine) {
         engine->addImportPath(QLatin1String(":/"));
     }
